==> jc-1.4.0.tar.gz: soot/javaToJimple/Util.h <==
// public class soot.javaToJimple.Util

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fb501b85de60e3ab soot_javaToJimple_Util

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_Util_H_
#define _JC_soot_javaToJimple_Util_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_types_Flags$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_util_Position$object;
struct _jc_soot_Type$object;
struct _jc_soot_tagkit_Host$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_Util$sub_refs	_jc_soot_javaToJimple_Util$sub_refs;
typedef struct _jc_soot_javaToJimple_Util$sub_nonrefs	_jc_soot_javaToJimple_Util$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_Util$refs	_jc_soot_javaToJimple_Util$refs;
typedef struct _jc_soot_javaToJimple_Util$nonrefs	_jc_soot_javaToJimple_Util$nonrefs;
typedef struct _jc_soot_javaToJimple_Util$object	_jc_soot_javaToJimple_Util$object;

typedef const struct _jc_soot_javaToJimple_Util$vmethods	_jc_soot_javaToJimple_Util$vmethods;
typedef const struct _jc_soot_javaToJimple_Util$vtable	_jc_soot_javaToJimple_Util$vtable;
typedef const struct _jc_soot_javaToJimple_Util$vtype	_jc_soot_javaToJimple_Util$vtype;

// Constructors
extern void _jc_soot_javaToJimple_Util$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_Util$object *);

// Static methods
extern void _jc_soot_javaToJimple_Util$method$addLineTag$be7e39b51a0702a2(_jc_env *, struct _jc_object *, jint, jint);
extern void _jc_soot_javaToJimple_Util$method$addLineTag$1708d233fe0fbae7(_jc_env *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_javaToJimple_Util$method$addLnPosTags$d688fb6975e31f57(_jc_env *, struct _jc_object *, jint, jint, jint, jint);
extern void _jc_soot_javaToJimple_Util$method$addLnPosTags$dd6f10fd39b4041c(_jc_env *, struct _jc_object *, struct _jc_polyglot_util_Position$object *);
extern void _jc_soot_javaToJimple_Util$method$addMethodLineTag$4e40b7597398e67c(_jc_env *, struct _jc_object *, jint, jint);
extern void _jc_soot_javaToJimple_Util$method$addMethodPosTag$f7344d9686748d51(_jc_env *, struct _jc_object *, jint, jint);
extern void _jc_soot_javaToJimple_Util$method$addPosTag$326ceab370f8ba8e(_jc_env *, struct _jc_object *, jint, jint);
extern void _jc_soot_javaToJimple_Util$method$addPosTag$547ae130ace9a22e(_jc_env *, struct _jc_object *, struct _jc_polyglot_util_Position$object *);
extern jint _jc_soot_javaToJimple_Util$method$getModifier$ca4fd8a4fb7aa448(_jc_env *, struct _jc_polyglot_types_Flags$object *);
extern struct _jc_soot_Type$object *_jc_soot_javaToJimple_Util$method$getSootType$38f4460e17ab2846(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_javaToJimple_Util$vmethods {
};

// Vtable
struct _jc_soot_javaToJimple_Util$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_Util$vmethods	soot_javaToJimple_Util;
};

// Vtype
struct _jc_soot_javaToJimple_Util$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_Util$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_Util$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_Util$refs {
    _jc_soot_javaToJimple_Util$sub_refs	soot_javaToJimple_Util;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_Util$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_Util$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_Util$sub_nonrefs	soot_javaToJimple_Util;
};

// Object instance structure
struct _jc_soot_javaToJimple_Util$object {
	_jc_soot_javaToJimple_Util$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_Util$vtype	*vtype;
	_jc_soot_javaToJimple_Util$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_Util$vtype _jc_soot_javaToJimple_Util$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_Util, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_Util$class_object;

#endif	/* _JC_soot_javaToJimple_Util_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/Util.h <==
// public class soot.javaToJimple.Util

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fb501b85de60e3ab soot_javaToJimple_Util

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_Util_H_
#define _JC_soot_javaToJimple_Util_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_types_Flags$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_util_Position$object;
struct _jc_soot_Type$object;
struct _jc_soot_tagkit_Host$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_Util$sub_refs	_jc_soot_javaToJimple_Util$sub_refs;
typedef struct _jc_soot_javaToJimple_Util$sub_nonrefs	_jc_soot_javaToJimple_Util$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_Util$refs	_jc_soot_javaToJimple_Util$refs;
typedef struct _jc_soot_javaToJimple_Util$nonrefs	_jc_soot_javaToJimple_Util$nonrefs;
typedef struct _jc_soot_javaToJimple_Util$object	_jc_soot_javaToJimple_Util$object;

typedef const struct _jc_soot_javaToJimple_Util$vmethods	_jc_soot_javaToJimple_Util$vmethods;
typedef const struct _jc_soot_javaToJimple_Util$vtable	_jc_soot_javaToJimple_Util$vtable;
typedef const struct _jc_soot_javaToJimple_Util$vtype	_jc_soot_javaToJimple_Util$vtype;

// Constructors
extern void _jc_soot_javaToJimple_Util$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_Util$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_soot_javaToJimple_Util$method$addLineTag$be7e39b51a0702a2(_jc_env *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_Util$method$addLineTag$1708d233fe0fbae7(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_Util$method$addLnPosTags$d688fb6975e31f57(_jc_env *, struct _jc_object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_Util$method$addLnPosTags$dd6f10fd39b4041c(_jc_env *, struct _jc_object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_Util$method$addMethodLineTag$4e40b7597398e67c(_jc_env *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_Util$method$addMethodPosTag$f7344d9686748d51(_jc_env *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_Util$method$addPosTag$326ceab370f8ba8e(_jc_env *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_Util$method$addPosTag$547ae130ace9a22e(_jc_env *, struct _jc_object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_javaToJimple_Util$method$getModifier$ca4fd8a4fb7aa448(_jc_env *, struct _jc_polyglot_types_Flags$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_javaToJimple_Util$method$getSootType$38f4460e17ab2846(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_javaToJimple_Util$vmethods {
};

// Vtable
struct _jc_soot_javaToJimple_Util$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_Util$vmethods	soot_javaToJimple_Util;
};

// Vtype
struct _jc_soot_javaToJimple_Util$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_Util$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_Util$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_Util$refs {
    _jc_soot_javaToJimple_Util$sub_refs	soot_javaToJimple_Util;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_Util$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_Util$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_Util$sub_nonrefs	soot_javaToJimple_Util;
};

// Object instance structure
struct _jc_soot_javaToJimple_Util$object {
	_jc_soot_javaToJimple_Util$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_Util$vtype	*vtype;
	_jc_soot_javaToJimple_Util$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_Util$vtype _jc_soot_javaToJimple_Util$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_Util, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_Util$class_object;

#endif	/* _JC_soot_javaToJimple_Util_H_ */
